#!/usr/bin/env python 

import sys

__description__ = '''The script creates files to compile user provided keywords
 for domain selection and classification'''
__author__ = "Malvika Sharan <malvika.sharan@uni-wuerzburg.de>"
__email__ = "malvika.sharan@uni-wuerzburg.de"


def keyword_domains_files(kw_file_path, keywords):
    with open(kw_file_path+'/keywords_for_domain_selection.txt',
              'w') as out_fh:
        if ',' in keywords:
            for each_kw in keywords.split(','):
                if ' ' in each_kw:
                    each_kw.replace(' ', '-')
                out_fh.write('%s\n' % each_kw)
        else:
            out_fh.write(keywords)
            print("------\nSingle keyword for domain selection "
                  "has been given.")
            print("Multiple keywords can be provided as comma separated "
                  "list.\n------")

def keyword_class_files(kw_file_path, keywords):
    with open(kw_file_path+'/keywords_for_result_classification.txt',
              'w') as out_fh:
        if ',' in keywords:
            out_fh.write('\n'.join(keywords.split(',')))
        else:
            out_fh.write(keywords)
            print("------\nSingle keyword for result "
                  "classification has been given.")
            print("Multiple keywords can be provided as "
                  "comma separated list.\n------")

if __name__ == '__main__':
    kw_file_path = sys.argv[1]
    keywords = sys.argv[2]
    keyword_domains_files(kw_file_path, keywords)



#!/usr/bin/env python 

import os       
import sys
import argparse

__description__ = "Sorts secondary structre and sequence from PDB"
__author__ = "Malvika Sharan <malvika.sharan@uni-wuerzburg.de>"
__email__ = "malvika.sharan@uni-wuerzburg.de"


parser = argparse.ArgumentParser()
parser.add_argument("-i","--pdb_ss_file",help="input secondary structure")
parser.add_argument("-seq","--pdb_seq_path",help="output pdb sequence")
parser.add_argument("-str","--pdb_str_path", help="output pdb structure")
args = parser.parse_args()

def main():
    "Sorts secondary structre and sequence from PDB"
    sequence_id_dict = {}
    out_seq_file = args.pdb_seq_path+'/pdb_sequence.txt'
    out_ss_file = args.pdb_str_path+'/pdb_secstr.txt'
    
    with open(args.pdb_ss_file) as in_fh:
        with open(out_seq_file, 'w') as out_seq_fh:
            with open(out_ss_file, 'w') as out_ss_fh:
                for data in in_fh.read().split('>'):
                    if "sequence" in data:
                        seq_id = data.split(':')[0]
                        sequence_id_dict[seq_id] = data
                        out_seq_fh.write('>%s'%data)
                    elif "secstr" in data:
                        str_id = data.split(':')[0]
                        data = data.replace(' ', '0')
                        seq_len = (len(sequence_id_dict[str_id]) - len(data))
                        for short in range(int(seq_len)):
                            data = data.strip()+'0'
                        out_ss_fh.write('>%s'%data)
                            
if __name__ == '__main__':
    
    main()   



#!/usr/bin/env python 

import argparse
import os
try:
    import xml.etree.ElementTree as ET
except ImportError:
    print('Python package xmlis missing. Please install/update.')
    sys.exit(0)
import re

__description__ = "Compiles InterProScan data from XML files to table"
__author__ = "Malvika Sharan <malvika.sharan@uni-wuerzburg.de>"
__email__ = "malvika.sharan@uni-wuerzburg.de"


def main():
    parser = argparse.ArgumentParser(description=__description__)
    parser.add_argument("interpro_analysis_path")
    parser.add_argument("interpro_xml")
    args = parser.parse_args()

    interpro_xml_parsing = InterproXmlParsing(
        args.interpro_analysis_path, args.interpro_xml)
    interpro_xml_parsing.regex_interpro_xml_parsing()
    
class InterproXmlParsing(object):
    def __init__(self, interpro_analysis_path,
                 interpro_xml):
        self._interpro_analysis_path = interpro_analysis_path
        self._interpro_xml = interpro_xml
        
    def regex_interpro_xml_parsing(self):
        '''Compiles InterProScan data from XML files to table'''
        interproid = open(
            self._interpro_analysis_path+'/interproid.tbl', 'w')
        only_id_ipr_xml = open(
            self._interpro_analysis_path+'/only_id_ipr_xml.txt', 'w')
        ipr_data_removed = open(
            self._interpro_analysis_path+'/ipr_data_removed.txt', 'w')
        
        tree = ET.parse(self._interpro_xml)
        root = tree.getroot()
        
        for data in root.findall('interpro'):
            abstract_list = []
            member_db_list = []
            
            ipr_id = data.attrib.get('id')
            name = data.find('name').text
            #print(ipr_id, name)
            only_id_ipr_xml.write('%s\t%s\n'%(ipr_id, name))
            
            member_list = data.findall('./member_list/*')
            external_doc = data.findall('./external_doc_list/*')
            db_list = [member_list, external_doc]
            for db_data in db_list:
                for db_elem in db_data:
                    member_db_list.append(
                        db_elem.attrib.get('dbkey'))
            whole_external_members = "|".join(
                sorted(list(set(member_db_list))))
            main_abstract = data.find('abstract').text
            abstract_list.append(main_abstract.replace(
                '\n', ' ').replace('[', ''))
            abstract_data = data.findall('./abstract/*')
            for abs_elem in abstract_data:
                abs_unordered = ET.tostring(abs_elem).strip()
                abs_ordered = str(abs_unordered).replace(
                    "b'<p>", "").replace("</p>'", "")
                for each_abs_elem in abs_ordered.split('\n'):
                    try:
                        abs_list_elt = re.sub(
                        '<[A-Za-z\/][^>]*>', '', each_abs_elem).replace(
                        "\\n", "").replace("'b'.", "").replace(
                            "]", "").replace("[", "").replace(
                            "b')", "").replace("b'", "").replace(
                        "'", "").replace(" ,", " ").replace(
                        "()", "").replace(" .", ".").replace(",,", "")
                        if len(abs_list_elt) > 2:
                            abstract_list.append(abs_list_elt)
                    except AttributeError:
                        pass
            full_abstract = (''.join(abstract_list))
            whole_abstract = re.sub(r'\s+', ' ', full_abstract)
            for external_members in member_db_list:
                try:
                    interproid.write('\t'.join([ipr_id, external_members,
                                  name, whole_abstract,
                                  whole_external_members])+'\n')
                except UnicodeEncodeError:
                    interproid.write('\t'.join([ipr_id, external_members,
                                  name, repr(whole_abstract),
                                  whole_external_members])+'\n')
                
            
        for deleted_data in root.findall('deleted_entries'):
            for ipr_id_info in deleted_data:
                ipr_id = ipr_id_info.attrib.get('id').strip()
                ipr_data_removed.write('%s\n'%ipr_id)
        ipr_data_removed.close()
        only_id_ipr_xml.close()
        interproid.close()  
        
if __name__ == "__main__":

    main()



#!/usr/bin/env python 

import sys
try:
    import urllib.request
    from urllib.request import urlopen
except ImportError:
    print('Python package urllib is missing. Please install/update.\n')
    sys.exit(0)

__description__ = "Downloads the complete proteome data from UniProt."
__author__ = "Malvika Sharan <malvika.sharan@uni-wuerzburg.de>"
__email__ = "malvika.sharan@uni-wuerzburg.de"

def format_uniprot_table(proteome_table, uniprot_link):
    '''Downloads protein information
    table from UniProt database for
    the selected taxonomy id'''
    try:
        response = urlopen(uniprot_link)
        for entry in str(response.read()).split('\\n'):
            if not entry == "'" and not entry == '"':
                if not entry.startswith("b'Entry") and not entry.startswith('b"Entry'):
                    proteome_table.write("%s\n" % '\t'.join(list(entry.split('\\t'))))
        print('"\nDownloaded protein information using UniProt link: %s\n"' % (
            uniprot_link))
    except:
        print(
            "UniProt entry is apparently deleted, please check: %s"
            % uniprot_link)
    
if __name__ == '__main__':
    proteome_table = sys.argv[1]
    uniprot_query = sys.argv[2]
    if "http://www.uniprot.org/" in uniprot_link:
        format_uniprot_table(proteome_table, uniprot_query)
    else:
        try:
            format_uniprot_table(proteome_table, uniprot_query)
        except KeyError:
            print("Please provide query UniProt ids or a taxonomy id for UniProt table retrieval.")



#!/usr/bin/env python 

import sys
from datetime import datetime as DT

__description__ = '''Find the current version of InterProData'''
__author__ = "Malvika Sharan <malvika.sharan@uni-wuerzburg.de>"
__email__ = "malvika.sharan@uni-wuerzburg.de"


def read_html_file(input_file, output_file):
    month_dict = {'Jan': 1, 'Feb': 2, 'Mar': 3, 'Apr': 4, 'May': 5,
                  'Jun': 6, 'Jul': 7, 'Aug': 8, 'Sep': 9, 'Oct': 10,
                  'Nov': 11, 'Dec': 12}
    with open(input_file) as in_fh:
        version_link = {}
        version_list = []
        for entry in in_fh.read().split('<pre>')[1].split('\n'):
            if 'Directory' in entry and not 'lookup_service' \
            in entry and not 'users' in entry and not 'old_releases' in entry:
                date_data = entry.split('Directory')[0].strip().replace(':', ' ').split(' ')
                year = int(date_data[0])
                month = int(month_dict[date_data[1]])
                date = int(date_data[2])
                try:
                    time = int(date_data[3])
                except IndexError:
                    time = 0
                version = entry.split('/</a>')[0].split('">')[-1]
                version_link[DT(year, month, date, time)] = version
                version_list.append(DT(year, month, date, time))
        latest_version = max(version_list)
        print("Current version: %s" % version_link[latest_version])
        with open(output_file, 'w') as out_fh:
            out_fh.write(version_link[latest_version])

if __name__ == '__main__':
    input_file = sys.argv[1]
    output_file = sys.argv[2]
    read_html_file(input_file, output_file)



#!/usr/bin/env python

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(name='bio-APRICOT',
      version='1.0.2',
      description='Sequence-based identification and characterization of protein classes',
      author='Malvika Sharan',
      author_email='malvikasharan@gmail.com',
      url='https://www.python.org/pypi/bio-apricot',
      packages=['apricotlib', 'bin'],
      install_requires=[
        "biopython >= 1.66",
        "requests >= 2.10.0",
        "matplotlib >= 1.5.1",
        "openpyxl >= 2.3.1",
        "numpy >= 1.9.0",
        "scipy >= 0.16.0"
    ],
    scripts=['bin/apricot'],
    license='ISC License (ISCL)',
    long_description=open('README.rst').read(),
    classifiers=[
        'License :: OSI Approved :: ISC License (ISCL)',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
    ]
)   
